@@ -24,6 +24,8 @@ def _get_auth_token(audience):
 def call(service_name, service_path=None, **kwargs):
     auth = {"Authorization": "Bearer " + _get_auth_token(MEDIATOR_URL)}
     r = requests.post(MEDIATOR_URL, headers=auth, json=kwargs)
+    if r.status_code >= 500:
+        r.raise_for_status()
     return r
 
 
@@ -64,15 +66,61 @@ def auth(permission):
     return wrap
 
 
+def _trim_document_path(path):
+    return "/".join(path.split("/")[5:])
+
+
+def repo_name(wid, cid):
+    return "{}-{}".format(wid, cid)
+
+
+class Asset:
+    def __init__(self, path):
+        path_parts = path.split("/")
+        self.id = path_parts[-1]
+        self.type = path_parts[-2]
+        if len(path_parts) > 2:
+            self.parent = Asset("/".join(path_parts[:-2]))
+        else:
+            self.parent = None
+
+
 class ParsedRequest:
     def __init__(self, request: Request):
         data = request.json
         self.user_info = user_info(request)
         self.data = data
-        self.repo = "{}-{}".format(data.get("wid"), data.get("cid"))
+        self.repo = repo_name(data.get("wid"), data.get("cid"))
         self.change_ref = "{}/{}/{}".format(
             data.get("sid"), self.user_info.get("user_id"), data.get("change_id")
         )
         self.plan_ref = "tf/plan/{}".format(self.change_ref)
         self.apply_ref = "tf/apply/{}".format(data.get("sid"))
         self.source_apply_ref = "tf/apply/{}".format(data.get("source_sid"))
+
+
+class DBEvent:
+    def __init__(self, event):
+        value = event["value"] or event["oldValue"]
+        self.asset = Asset(_trim_document_path(value["name"]))
+        self.data = self._raise_values(value["fields"])
+
+    def _raise_value(self, value_obj):
+        value_type = next(iter(value_obj))
+        if value_type == "mapValue":
+            value = self._raise_values(value_obj[value_type])
+        elif value_type == "arrayValue":
+            value = [self._raise_value(v) for v in value_obj[value_type]["values"]]
+        elif value_type == "referenceValue":
+            value = Asset(_trim_document_path(value_obj[value_type]))
+        else:
+            value = value_obj[value_type]
+        return value
+
+    def _raise_values(self, fields):
+        values = {}
+        for key in fields:
+            value_type = next(iter(fields[key]))
+            values[key] = self._raise_value(fields[value_type])
+        return values
+
